@@ -28,8 +28,8 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include <signal.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <iostream.h>
-#include <iomanip.h>
+#include <iostream>
+#include <iomanip>
 #include <stdarg.h>
 
 #if HAVE_DIRENT_H
@@ -67,7 +67,7 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 # include "ControlWindow.h"
 # include "MessageWindow.h"
 extern class ControlWindow* controlwindow_p;
-#endif NO_GRAPHICS
+#endif 
 
 ArenaBase::ArenaBase()
 {
@@ -143,7 +143,7 @@ ArenaBase::set_state( const state_t st )
       
       controlwindow_p->set_window_title( infotext );
     }
-#endif NO_GRAPHICS
+#endif 
 }
 
 void 
@@ -173,8 +173,9 @@ ArenaBase::interrupt_tournament()
 void
 ArenaBase::save_statistics_to_file(String filename)
 {
-  int mode = _IO_OUTPUT;
-  ofstream file(filename.chars(), mode);
+  
+  
+  ofstream file(filename.chars());
 
   stat_t* statp;
   Robot* robotp;
@@ -196,6 +197,8 @@ ArenaBase::save_statistics_to_file(String filename)
                << "  Total Points: " << statp->total_points << endl;
         }
     }
+    
+    
 }
 
 void
@@ -718,7 +721,7 @@ ArenaBase::step_paused_game()
 void
 ArenaBase::delete_lists(const bool kill_robots, const bool del_seq_list, 
                         const bool del_tourn_list, const bool del_arena_filename_list, 
-                        const bool del_robot_obj_list=true)
+                        const bool del_robot_obj_list)
 {
   // clear the lists;
 
