@@ -26,12 +26,14 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include <signal.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <iostream.h>
-#include <iomanip.h>
+#include <iostream>
+#include <iomanip>
 #include <stdarg.h>
 #include <sys/stat.h>
 #include <stdio.h>
 
+using namespace std;
+
 //#include "Gui.h"
 #include "ArenaRealTime.h"
 #include "ArenaController.h"
@@ -110,13 +112,16 @@ ArenaRealTime::set_filenames( String& log_fname,
     }
   else if( log_fname == "-" || log_fname == "STDOUT" )  // use stdout as log_file
     {
-      LOG_FILE.attach(STDOUT_FILENO);
+      cout << "Attach -- Muss gefixt werden in ArenaREaltime.cc 113" << endl;
+      //LOG_FILE.attach(STDOUT_FILENO);
       use_log_file = true;
       log_stdout = true;
     }
   else
     {
-      LOG_FILE.open(log_fname.chars(), ios::out, S_IRUSR | S_IWUSR);
+       //LOG_FILE.open(log_fname.chars(), ios::out, S_IRUSR | S_IWUSR);
+		LOG_FILE.open(log_fname.chars(), ios::out);
+		
       use_log_file = true;
       if( !LOG_FILE )
         {
@@ -125,7 +130,6 @@ ArenaRealTime::set_filenames( String& log_fname,
           use_log_file = false;
         }
     }
-  
   if( message_fname == "" )
     {
       use_message_file = false;
@@ -135,7 +139,7 @@ ArenaRealTime::set_filenames( String& log_fname,
       if( !log_stdout )
         {
           use_message_file = true;
-          message_file.attach( STDOUT_FILENO );
+          //message_file.attach( STDOUT_FILENO );
         }
       else
         {
@@ -145,7 +149,7 @@ ArenaRealTime::set_filenames( String& log_fname,
   else
     {
       use_message_file = true;
-      message_file.open( message_fname.chars(), ios::out, S_IRUSR | S_IWUSR );
+      //message_file.open( message_fname.chars(), ios::out, S_IRUSR | S_IWUSR );
       if( !message_file )
         {
           Error( false, "Couldn't open message file. Message file disabled",
@@ -392,7 +396,7 @@ ArenaRealTime::timeout_function()
 {
 #ifndef NO_GRAPHICS
       int old_total = (int)total_time;
-#endif NO_GRAPHICS
+#endif 
 
   if( state != PAUSED )
     {
