@@ -91,7 +91,7 @@ ArenaReplay::timeout_function()
       {
 #ifndef NO_GRAPHICS
         int old_total = (int)current_replay_time;
-#endif NO_GRAPHICS
+#endif 
 
         parse_this_interval();
 
@@ -121,7 +121,7 @@ ArenaReplay::timeout_function()
           snprintf(msg, 63, _("Game %d of sequence %d"), game_nr, sequence_nr);
           print_message( "RealTimeBattle", (String)msg );
         }
-#endif NO_GRAPHICS
+#endif 
       set_state( GAME_IN_PROGRESS );
       break;
 
@@ -208,7 +208,7 @@ ArenaReplay::parse_this_time_index()
 #ifndef NO_GRAPHICS
         if( !no_graphics )
           the_gui.get_arenawindow_p()->draw_moving_objects( true );
-#endif NO_GRAPHICS
+#endif 
 
   // check if robots have died and set their points
   if( robots_killed_this_round != 0 )
@@ -736,6 +736,8 @@ ArenaReplay::set_filenames( String& replay_fname, String& message_fname,
                             const String& statistics_fname,
                             const String& option_fname )
 {
+	
+ /*
   if( replay_fname != "-" )
     {
       log_file.open( replay_fname.chars() );
@@ -775,6 +777,7 @@ ArenaReplay::set_filenames( String& replay_fname, String& message_fname,
 
   statistics_file_name = statistics_fname;
   option_file_name = option_fname;
+  */
 }
 
 // Changes game when replaying to fast forward, rewind or normal speed
@@ -1094,7 +1097,7 @@ ArenaReplay::search_forward( const List<String>& search_strings )
 String
 ArenaReplay::search_backwards( const String& search_letters )
 {
-  if( log_from_stdin )
+ /* if( log_from_stdin )
     return "";
 
   char letter='?';
@@ -1114,13 +1117,15 @@ ArenaReplay::search_backwards( const String& search_letters )
       return (String) buffer;
     }
 
+ 
+  */
   return "";
 }
 
 void
 ArenaReplay::beginning_of_prev_line()
 {
-  char letter='?';
+ /* char letter='?';
   bool already_found_one_line = false;
   while( ( letter != '\n' || !already_found_one_line ) &&
          log_file.tellg() != 0 )
@@ -1133,12 +1138,13 @@ ArenaReplay::beginning_of_prev_line()
           letter = '?';
         }
     }
-  log_file.get( letter );
+  log_file.get( letter ); */
 }
 
 void
 ArenaReplay::beginning_of_current_line()
 {
+  /*
   char letter='?';
   while( letter != '\n' && log_file.tellg() != 0 )
     {
@@ -1146,11 +1152,13 @@ ArenaReplay::beginning_of_current_line()
       letter = log_file.peek();
     }
   log_file.get( letter );
+  */
 }
 
 void
 ArenaReplay::make_statistics_from_file()
 {
+ /*
   List<String> str_list;
   str_list.insert_last( new String("DR") );
   str_list.insert_last( new String("L") );
@@ -1238,11 +1246,13 @@ ArenaReplay::make_statistics_from_file()
   log_file.clear();
 
   current_replay_time = 0;
+*/
 }
 
 void
 ArenaReplay::get_time_positions_in_game()
 {  
+  /*
   String letter_list = "TGHSMCDR";
   char letter;
   char buffer[400];
@@ -1394,6 +1404,7 @@ ArenaReplay::get_time_positions_in_game()
   log_file.clear();
 
   last_time_info = time_pos_index - 1;
+  */
 }
 
 // Finds the index of time_position_in_log which has the largest time
