@@ -34,7 +34,7 @@ Dialog::Dialog( const String& info, const List<String>& button_labels,
 {
   // The window
 
-  window_p = gtk_window_new( GTK_WINDOW_DIALOG );
+  window_p = gtk_window_new( GTK_WINDOW_TOPLEVEL );
   gtk_window_set_title( GTK_WINDOW( window_p ), "RealTimeBattle" );
   gtk_widget_set_name( window_p, "RTB Dialog" );
   gtk_window_set_policy( GTK_WINDOW( window_p ), FALSE, FALSE, FALSE );
