@@ -49,15 +49,12 @@ MessageWindow::MessageWindow( const int default_width,
   gtk_container_border_width( GTK_CONTAINER( window_p ), 12 );
 
   if( default_width != -1 && default_height != -1 )
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
     {
       gtk_window_set_default_size( GTK_WINDOW( window_p ),
                                    default_width, default_height );
       gtk_widget_set_usize( window_p , 300, 110 );
     }
-#else
-    gtk_widget_set_usize( window_p, default_width, default_height );
-#endif
+
   if( default_x_pos != -1 && default_y_pos != -1 )
     gtk_widget_set_uposition( window_p, default_x_pos, default_y_pos );
 
@@ -97,7 +94,6 @@ MessageWindow::MessageWindow( const int default_width,
       gtk_widget_show( button );
     }
     
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   GtkObject* hadj = gtk_adjustment_new( 0.0, 0.0, 100.0, 1.0, 1.0, 1.0 );
   GtkObject* vadj = gtk_adjustment_new( 0.0, 0.0, 100.0, 1.0, 1.0, 1.0 );
   GtkWidget* scrolled_win =
@@ -109,7 +105,6 @@ MessageWindow::MessageWindow( const int default_width,
 
   gtk_box_pack_start( GTK_BOX (vbox), scrolled_win, TRUE, TRUE, 0 );
   gtk_widget_show( scrolled_win );
-#endif
 
   char* titles[2] = { _(" Robot "), _(" Message ") };
   clist = gtk_clist_new_with_titles( 2, titles );
@@ -122,7 +117,6 @@ MessageWindow::MessageWindow( const int default_width,
   gtk_clist_set_column_justification( GTK_CLIST( clist ), 1,
                                       GTK_JUSTIFY_LEFT );
   gtk_clist_column_titles_passive( GTK_CLIST( clist ) );
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   gtk_clist_set_shadow_type( GTK_CLIST( clist ), GTK_SHADOW_IN );
   gtk_container_add( GTK_CONTAINER( scrolled_win ), clist );
 
@@ -136,15 +130,8 @@ MessageWindow::MessageWindow( const int default_width,
   clist_style->bg[GTK_STATE_SELECTED] = make_gdk_colour( 0xf0d2b4 );
   clist_style->fg[GTK_STATE_SELECTED] = *(the_gui.get_fg_gdk_colour_p());
   gtk_widget_set_style( clist, clist_style );
-#else
-  gtk_clist_set_border( GTK_CLIST( clist ), GTK_SHADOW_IN );
-  gtk_clist_set_policy( GTK_CLIST( clist ),
-                        GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
-  gtk_box_pack_start( GTK_BOX( vbox ), clist, TRUE, TRUE, 0 );
-#endif
   gtk_widget_show( clist );
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   rtb_message_row_style = gtk_rc_get_style(window_p);
   if( rtb_message_row_style == NULL )
     rtb_message_row_style = gtk_style_new();
@@ -170,7 +157,6 @@ MessageWindow::MessageWindow( const int default_width,
   robot_message_row_style->bg[GTK_STATE_SELECTED] = make_gdk_colour( 0xf0d2b4 );
   robot_message_row_style->fg[GTK_STATE_NORMAL] = *( the_gui.get_fg_gdk_colour_p() );
   robot_message_row_style->fg[GTK_STATE_SELECTED] = *( the_gui.get_fg_gdk_colour_p() );
-#endif
 
   if( window_shown = ( controlwindow_p->is_messagewindow_checked() ) )
     gtk_widget_show_now( window_p );
@@ -199,41 +185,23 @@ MessageWindow::add_message( const String& name_of_messager,
 {
   if( window_shown )
     {
-      //      gtk_clist_freeze( GTK_CLIST( clist ) );
       if( viewed_robot != NULL &&
           viewed_robot->get_robot_name() != name_of_messager &&
           name_of_messager != "RealTimeBattle" )
         return;
 
       char* lst[2] = { name_of_messager.non_const_chars(),
-                       message.non_const_chars() };
-  
+                       g_utf8_normalize (message.non_const_chars(), -1, G_NORMALIZE_ALL) };
+  					   
       int row = 0;
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
       row = gtk_clist_insert( GTK_CLIST( clist ), row, lst );
-#else
-      gtk_clist_insert( GTK_CLIST( clist ), row, lst );
-#endif
 
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
       if( name_of_messager == "RealTimeBattle" )
         gtk_clist_set_row_style( GTK_CLIST( clist ), row, rtb_message_row_style );
       else
         gtk_clist_set_row_style( GTK_CLIST( clist ), row, robot_message_row_style );
-#else
-      GdkColor* fg_colour = NULL;
-      if( name_of_messager == "RealTimeBattle" )
-        fg_colour = the_gui.get_rtb_message_gdk_colour_p();
-      else
-        fg_colour = the_gui.get_fg_gdk_colour_p();
 
-      gtk_clist_set_foreground( GTK_CLIST( clist ), row,
-                                fg_colour );
-      gtk_clist_set_background( GTK_CLIST( clist ), row,
-                                the_gui.get_bg_gdk_colour_p() );
-#endif
-      //      gtk_clist_thaw( GTK_CLIST( clist ) );
     }
 }
 
@@ -264,7 +232,7 @@ MessageWindow::set_window_shown( bool win_shown )
 }
 
 // Warning: event can be NULL, do not use event!
-void
+gboolean
 MessageWindow::hide_window( GtkWidget* widget, GdkEvent* event,
                             class MessageWindow* messagewindow_p )
 {
@@ -275,13 +243,10 @@ MessageWindow::hide_window( GtkWidget* widget, GdkEvent* event,
       if( controlwindow_p->is_messagewindow_checked() )
         {
           GtkWidget* menu_item = controlwindow_p->get_show_message_menu_item();
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
           gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM( menu_item ), FALSE );
-#else
-          gtk_check_menu_item_set_state( GTK_CHECK_MENU_ITEM( menu_item ), FALSE );
-#endif
         }
     }
+	return true;
 }
 
 void
