@@ -21,10 +21,12 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <fstream.h>
+#include <fstream>
 #include <math.h>
 #include <stdlib.h>
 
+using namespace std;
+
 #ifdef HAVE_LOCALE_H
 # include <locale.h>
 #endif
@@ -501,7 +503,7 @@ Options::read_options_file(String file_string, const bool as_default)
           {
             double option_value;
             file >> option_value;
-            file.get(buffer,100,'\n');
+            //file.get(buffer,100,'\n');
             option_value = min( option_value,
                                 all_double_options[i].max_value );
             option_value = max( option_value,
@@ -510,6 +512,7 @@ Options::read_options_file(String file_string, const bool as_default)
             if(as_default)
               all_double_options[i].default_value = option_value;
             option_found_flag = true;
+			
           }
 
       for(int i=0;i<LAST_LONG_OPTION;i++)
@@ -522,11 +525,12 @@ Options::read_options_file(String file_string, const bool as_default)
               {
                 String temp_string;
                 file >> temp_string;
+							
                 while( temp_string[0] == ' ' )
                   temp_string = get_segment(temp_string,1,-1);
                 option_value = str2hex(temp_string);
               }
-            file.get(buffer,100,'\n');
+            //file.get(buffer,100,'\n');
             option_value = min( option_value,
                                 all_long_options[i].max_value );
             option_value = max( option_value,
@@ -535,7 +539,7 @@ Options::read_options_file(String file_string, const bool as_default)
             if(as_default)
               all_long_options[i].default_value = option_value;
             option_found_flag = true;
-          }
+	  }
 
       for(int i=0;i<LAST_STRING_OPTION;i++)
         if(option_name == all_string_options[i].label )
@@ -544,15 +548,16 @@ Options::read_options_file(String file_string, const bool as_default)
             file >> option_value;
             while( option_value[0] == ' ' )
               option_value = get_segment(option_value,1,-1);
-            file.get(buffer,100,'\n');
+            //file.get(buffer,100,'\n');
             all_string_options[i].value = option_value;
             if(as_default)
               all_string_options[i].default_value = option_value;
             option_found_flag = true;
-          }
-      if(!option_found_flag)
-        file.get(buffer,1000,'\n');        
-    }
+	  }
+     // if(!option_found_flag)
+     //   file.get(buffer,1000,'\n');  
+	 
+    } 
 }
 
 void
@@ -580,19 +585,29 @@ Options::save_all_options_to_file(String filename, const bool as_default)
     optionswindow_p->set_all_options();
 #endif
 
-  for(int i=0;i<LAST_DOUBLE_OPTION;i++)
+  for(int i=0;i<LAST_DOUBLE_OPTION;i++){
     file << all_double_options[i].label << ": " << all_double_options[i].value << endl;
-
+ 	//cout << all_double_options[i].label << ": " << all_double_options[i].value << endl;
+  }
+  
+  
   for(int i=0;i<LAST_LONG_OPTION;i++)
     {
-      if(all_long_options[i].datatype == ENTRY_INT)
+      if(all_long_options[i].datatype == ENTRY_INT){
         file << all_long_options[i].label << ": " << all_long_options[i].value << endl;
-      if(all_long_options[i].datatype == ENTRY_HEX)
+		//cout << all_long_options[i].label << ": " << all_long_options[i].value << endl;
+	  }
+	  
+      if(all_long_options[i].datatype == ENTRY_HEX){ 
         file << all_long_options[i].label << ": " << hex2str(all_long_options[i].value) << endl;
+		//cout << all_long_options[i].label << ": " << hex2str(all_long_options[i].value) << endl;
+	  }
     }
 
-  for(int i=0;i<LAST_STRING_OPTION;i++)
+  for(int i=0;i<LAST_STRING_OPTION;i++){
     file << all_string_options[i].label << ": " << all_string_options[i].value << endl;
+ 	//cout << all_string_options[i].label << ": " << all_string_options[i].value << endl;
+  }
 }
 
 option_return_t
@@ -654,4 +669,4 @@ Options::close_optionswindow()
     }
 }
 
-#endif NO_GRAPHICS
+#endif
