@@ -44,15 +44,11 @@ ScoreWindow::ScoreWindow( const int default_width,
   gtk_container_border_width( GTK_CONTAINER( window_p ), 12 );
 
   if( default_width != -1 && default_height != -1 )
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
     {
       gtk_window_set_default_size( GTK_WINDOW( window_p ),
                                    default_width, default_height );
       gtk_widget_set_usize( window_p , 175, 80 );
     }
-#else
-    gtk_widget_set_usize( window_p, default_width, default_height );
-#endif
   if( default_x_pos != -1 && default_y_pos != -1 )
     gtk_widget_set_uposition( window_p, default_x_pos, default_y_pos );
 
@@ -60,7 +56,6 @@ ScoreWindow::ScoreWindow( const int default_width,
                       (GtkSignalFunc) ScoreWindow::hide_window,
                       (gpointer) this );
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   GtkObject* hadj = gtk_adjustment_new ( 0.0, 0.0, 100.0, 1.0, 1.0, 1.0 );
   GtkObject* vadj = gtk_adjustment_new ( 0.0, 0.0, 100.0, 1.0, 1.0, 1.0 );
   GtkWidget* scrolled_win =
@@ -70,7 +65,6 @@ ScoreWindow::ScoreWindow( const int default_width,
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
   gtk_container_add( GTK_CONTAINER( window_p ), scrolled_win );
   gtk_widget_show ( scrolled_win );
-#endif
 
   char * titles[6] = { "", _("Name"), _("Energy"), _("Place"),
                        _("Last"), _("Score") };
@@ -98,7 +92,6 @@ ScoreWindow::ScoreWindow( const int default_width,
   gtk_signal_connect( GTK_OBJECT( clist ), "select_row",
                       (GtkSignalFunc) new_robot_selected, this );
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
   gtk_clist_set_column_resizeable( GTK_CLIST( clist ), 0, FALSE );
   gtk_clist_set_column_max_width( GTK_CLIST( clist ), 0, 5 );
   gtk_clist_set_shadow_type( GTK_CLIST( clist ), GTK_SHADOW_IN );
@@ -117,12 +110,6 @@ ScoreWindow::ScoreWindow( const int default_width,
   clist_style->bg[GTK_STATE_SELECTED] = make_gdk_colour( 0xf0d2b4 );
   clist_style->fg[GTK_STATE_SELECTED] = *(the_gui.get_fg_gdk_colour_p());
   gtk_widget_set_style( clist, clist_style );
-#else
-  gtk_clist_set_border( GTK_CLIST( clist ), GTK_SHADOW_IN );
-  gtk_clist_set_policy( GTK_CLIST( clist ), GTK_POLICY_AUTOMATIC,
-                        GTK_POLICY_AUTOMATIC);
-  gtk_container_add( GTK_CONTAINER( window_p ), clist );
-#endif
   gtk_widget_show( clist );
 
   if( window_shown = ( controlwindow_p->is_scorewindow_checked() ) )
@@ -163,24 +150,22 @@ ScoreWindow::set_window_title()
 // This function hides the window
 // Warning: event can be NULL, do not use event!
 //
-void
+gboolean
 ScoreWindow::hide_window( GtkWidget* widget, GdkEvent* event,
                           class ScoreWindow* scorewindow_p )
 {
   if( scorewindow_p->is_window_shown() )
     {
-      gtk_widget_hide( scorewindow_p->get_window_p() );
-      scorewindow_p->set_window_shown( false );
+	  gtk_widget_hide( scorewindow_p->get_window_p() );
+      
+	  scorewindow_p->set_window_shown( false );
       if( controlwindow_p->is_scorewindow_checked() )
         {
           GtkWidget* menu_item = controlwindow_p->get_show_score_menu_item();
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
           gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM( menu_item ), FALSE );
-#else
-          gtk_check_menu_item_set_state( GTK_CHECK_MENU_ITEM( menu_item ), FALSE );
-#endif
         }
     }
+ return true;
 }
 
 //
