@@ -27,7 +27,7 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #ifndef NO_GRAPHICS
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
-#endif NO_GRAPHICS
+#endif 
 
 #include <sys/stat.h>
 #if HAVE_DIRENT_H
@@ -49,8 +49,11 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include <stdlib.h>
 //#include <stdio.h>
 #include <string.h>
-#include <iostream.h>
-#include <fstream.h>
+#include <iostream>
+#include <fstream>
+# include <dirent.h>
+
+using namespace std;
 
 #include "Various.h"
 #include "IntlDefs.h"
@@ -62,7 +65,7 @@ extern class Options the_opts;
 #ifndef NO_GRAPHICS
 # include "ControlWindow.h"
 extern class ControlWindow* controlwindow_p;
-#endif NO_GRAPHICS
+#endif 
 extern bool no_graphics;
 
 void
@@ -89,7 +92,7 @@ Quit(const bool success)
     if( !no_graphics )
       delete controlwindow_p;
   }
-#endif NO_GRAPHICS
+#endif 
 
   if( !success )
     exit(EXIT_FAILURE);  
@@ -171,7 +174,7 @@ gdk2hex_colour(const GdkColor& col)
             ((col.green & 0xff) << 8) |
             ((col.red & 0xff) << 16) );
 }
-#endif NO_GRAPHICS
+#endif 
 
 void
 read_dirs_from_system(List<String>& robotdirs, List<String>& arenadirs)
@@ -380,11 +383,9 @@ parse_tournament_file( const String& fname, const StartTournamentFunction functi
   for(;;)
     {
       char buffer[200];
-      file >> buffer;
-      String word(buffer);
-
-      if( word == "" )
-        {
+      if ((file >> buffer).eof()){
+          
+          
           int robots_counted = robot_list.number_of_elements();
           int arenas_counted = arena_list.number_of_elements();
           
@@ -437,6 +438,7 @@ parse_tournament_file( const String& fname, const StartTournamentFunction functi
           return true;
         }
 
+      String word(buffer);
 
       if((make_lower_case(word) == "games/sequence:") || 
          (make_lower_case(word) == "g/s:"))
@@ -474,6 +476,7 @@ parse_tournament_file( const String& fname, const StartTournamentFunction functi
         looking_for = 2;
       else
         {
+        
           switch(looking_for)
             {
             case 0:
@@ -520,14 +523,14 @@ entry_handler( GtkWidget * entry, entry_t * entry_info )
             entry_text.erase(i);
           break;
         case ENTRY_DOUBLE:
-          if( !((entry_text[i] >= '0' && entry_text[i] <= '9') ||
+        /* if( !((entry_text[i] >= '0' && entry_text[i] <= '9') ||
                 (entry_text[i] == '.') ||
                 (entry_text[i] == '-' && i == 0 && entry_info->allow_sign ))  )
             entry_text.erase(i);
           if( entry_text[i] == '.' && !point_found )
             point_found = true;
           else if( entry_text[i] == '.' && point_found )
-            entry_text.erase(i);
+            entry_text.erase(i);*/
           break;
         case ENTRY_HEX:
           if( !(((entry_text[i] >= '0' && entry_text[i] <= '9') || 
@@ -547,7 +550,6 @@ entry_handler( GtkWidget * entry, entry_t * entry_info )
     gtk_entry_set_text(GTK_ENTRY(entry),entry_text.chars());
 }
 
-#if GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1
 gint
 int_compare(GtkCList* clist, gconstpointer ptr1, gconstpointer ptr2)
 {
@@ -723,6 +725,5 @@ string_case_insensitive_compare(GtkCList *clist, gconstpointer ptr1, gconstpoint
 
   return strcasecmp (text1, text2);
 }
-#endif
 
-#endif NO_GRAPHICS
+#endif
